==> zio-aws-cloudfront_2.13-5.17.104.7-sources.jar: zio/aws/cloudfront/model/GetCachePolicyResponse.scala <==
package zio.aws.cloudfront.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class GetCachePolicyResponse(
    cachePolicy: Option[zio.aws.cloudfront.model.CachePolicy] = None,
    eTag: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cloudfront.model.GetCachePolicyResponse = {
    import GetCachePolicyResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cloudfront.model.GetCachePolicyResponse
      .builder()
      .optionallyWith(cachePolicy.map(value => value.buildAwsValue()))(
        _.cachePolicy
      )
      .optionallyWith(eTag.map(value => value: java.lang.String))(_.eTag)
      .build()
  }
  def asReadOnly: zio.aws.cloudfront.model.GetCachePolicyResponse.ReadOnly =
    zio.aws.cloudfront.model.GetCachePolicyResponse.wrap(buildAwsValue())
}
object GetCachePolicyResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cloudfront.model.GetCachePolicyResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.cloudfront.model.GetCachePolicyResponse =
      zio.aws.cloudfront.model.GetCachePolicyResponse(
        cachePolicy.map(value => value.asEditable),
        eTag.map(value => value)
      )
    def cachePolicy: Option[zio.aws.cloudfront.model.CachePolicy.ReadOnly]
    def eTag: Option[String]
    def getCachePolicy
        : ZIO[Any, AwsError, zio.aws.cloudfront.model.CachePolicy.ReadOnly] =
      AwsError.unwrapOptionField("cachePolicy", cachePolicy)
    def getETag: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("eTag", eTag)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cloudfront.model.GetCachePolicyResponse
  ) extends zio.aws.cloudfront.model.GetCachePolicyResponse.ReadOnly {
    override val cachePolicy
        : Option[zio.aws.cloudfront.model.CachePolicy.ReadOnly] = scala
      .Option(impl.cachePolicy())
      .map(value => zio.aws.cloudfront.model.CachePolicy.wrap(value))
    override val eTag: Option[String] =
      scala.Option(impl.eTag()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.cloudfront.model.GetCachePolicyResponse
  ): zio.aws.cloudfront.model.GetCachePolicyResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-cloudfront_2.13-5.19.17.1-sources.jar: zio/aws/cloudfront/model/GetCachePolicyResponse.scala <==
package zio.aws.cloudfront.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class GetCachePolicyResponse(
    cachePolicy: Optional[zio.aws.cloudfront.model.CachePolicy] =
      Optional.Absent,
    eTag: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cloudfront.model.GetCachePolicyResponse = {
    import GetCachePolicyResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cloudfront.model.GetCachePolicyResponse
      .builder()
      .optionallyWith(cachePolicy.map(value => value.buildAwsValue()))(
        _.cachePolicy
      )
      .optionallyWith(eTag.map(value => value: java.lang.String))(_.eTag)
      .build()
  }
  def asReadOnly: zio.aws.cloudfront.model.GetCachePolicyResponse.ReadOnly =
    zio.aws.cloudfront.model.GetCachePolicyResponse.wrap(buildAwsValue())
}
object GetCachePolicyResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cloudfront.model.GetCachePolicyResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.cloudfront.model.GetCachePolicyResponse =
      zio.aws.cloudfront.model.GetCachePolicyResponse(
        cachePolicy.map(value => value.asEditable),
        eTag.map(value => value)
      )
    def cachePolicy: Optional[zio.aws.cloudfront.model.CachePolicy.ReadOnly]
    def eTag: Optional[String]
    def getCachePolicy
        : ZIO[Any, AwsError, zio.aws.cloudfront.model.CachePolicy.ReadOnly] =
      AwsError.unwrapOptionField("cachePolicy", cachePolicy)
    def getETag: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("eTag", eTag)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cloudfront.model.GetCachePolicyResponse
  ) extends zio.aws.cloudfront.model.GetCachePolicyResponse.ReadOnly {
    override val cachePolicy
        : Optional[zio.aws.cloudfront.model.CachePolicy.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.cachePolicy())
        .map(value => zio.aws.cloudfront.model.CachePolicy.wrap(value))
    override val eTag: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.eTag())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.cloudfront.model.GetCachePolicyResponse
  ): zio.aws.cloudfront.model.GetCachePolicyResponse.ReadOnly = new Wrapper(
    impl
  )
}
